# aws-opsworks-smooth-deploy
Deploy script executed inside AWS opsworks instances to avoid error request from ELB.


Before starting the deployment process, execute

```
aws_opsworks_smooth_deploy start
```

After the deployment process finish, execute

```
aws_opsworks_smooth_deploy finish
```
